/************** BEST VIEWED IN A CODE EDITOR 80 COLUMNS WIDE *******************
*
* Durahook Metal Pegboard Adapter
* Benjamen Johnson <3dprints.electronsmith.com>
* 2021040
*
* openSCAD Version: 2019.05 
* Licesnse: Creative Commons - Attribution - Share Alike
*           https://creativecommons.org/licenses/by-sa/4.0/
*******************************************************************************/
/*[Hidden]*/
version="V1.1";

SQUARE=0;ROUNDED=1;
// add a little bit to cuts to make them render properly
$dl = 0.01;

/*[Pegboard Properties]*/
/*******************************************************************************
*
*******************************************************************************/
// Diameter of the pegboard holes
hole_dia = 6.25;

// Spacing between the pegboard holes
hole_spacing = 25.4;

/*[Anchor Properties]*/
/*******************************************************************************
*
*******************************************************************************/
// Should the corners be square or rounded
corners = 1; //[0:Square, 1:Rounded]

// How much material do you want around the border?
border = 10;//[3:0.1:25.4]

// Thickness of the base
base_thickness = 0.7;//[0.4:0.1:2]

// width of the little pegboard hook on the DuraHook
durahook_dia = 5.5;

base_height = hole_spacing+2*border;
base_width = 2*border;
BASE_DEF = [base_width,base_height,base_thickness];

/*[Screw Options]*/
/*******************************************************************************
* 
*******************************************************************************/
// Diameter of the screw hole 
screw_dia = 3;

// How far should anchor sick through the pegboard?
anchor_len = 5;

// Space between the anchor prongs
gap=0.25;

/*[Stamp Options]*/
/*******************************************************************************
* Stamp Options
*******************************************************************************/
// Which font do you want to use
font = "REGISTRATION PLATE UK:style=Bold";

// How big you want the text
font_size = 6;//[0:0.5:10 ]

// How thick the font is (back to front)
font_thickness = 0.2;

/*******************************************************************************
* Make it
*******************************************************************************/
anchor_pos = anchor_len/2+base_thickness;
difference(){
    union(){
        if(corners == SQUARE)
            translate([0,0,base_thickness/2])
            cube(BASE_DEF,center=true);
            
        else
            translate([0,0,base_thickness/2])
            hull(){
                translate([0,-hole_spacing/2,0])
                cylinder(r=border,h=base_thickness,$fn=50,center=true);
                translate([0,hole_spacing/2,0])
                cylinder(r=border,h=base_thickness,$fn=50,center=true);
            }//end hull
            
        translate([0,-hole_spacing/2,anchor_pos])
        cylinder(d=hole_dia,h=anchor_len,$fn=50, center=true);

    } //end union
    
    //Create the internal part of the anchor
    translate([0,-hole_spacing/2,0])
    cutout();
    
    // make hole for DuraHook hook
    translate([0,hole_spacing/2,base_thickness/2])
    cylinder(d=durahook_dia,h=2*base_thickness,$fn=50,center=true);
             
    translate([0,0,font_thickness-$dl])
    rotate([180,0,0])
    stamp_version(version, font_size, font_thickness);

} //end difference

/*******************************************************************************
* module to cutout the cross hair hole
*******************************************************************************/
module cutout(){
    render()
    union(){
        translate([0,0,anchor_len/2])
        cube([hole_dia+$dl,gap,anchor_len*2],center=true);
            
        translate([0,0,anchor_len/2])
        cube([gap,hole_dia+$dl,anchor_len*2],center=true);
        
        translate([0,0,-$dl])
        cylinder(d1=screw_dia, d2=gap,h=anchor_len,$fn=50);

    } //end union    
} //end module

/*******************************************************************************
* Module for putting the version number on the print
*******************************************************************************/
module stamp_version(version_text,size,thickness){
    color("white")
    linear_extrude(height = thickness)
        text(text = version_text, font = font, size = size, valign="center",halign = "center");
} // end module
